

This is not actually a hook, but a rule that we need to put into our hooks eventually. And it is that we should never compact without writing out a detailed plan for the next stage and a detailed report about what we have done in this current conversation or stage that we have been working on.

This should make sure to include all performance metrics and any potential reviews of the logs or our conversation that would warrant us to try and update the system in the future.

The cutoffs should be much earlier in the token process than the actual compaction occurs. We should basically be self-compacting as soon as a task is done and then clearing our contacts because we do not want overlap across all of the tasks.

An example of how you implement the hooks and such is in the hooks-test/ directory where we tried to build out an example of how to use hooks within Claude Code effectively so that we can do the things that the readme for that directory says.


